@@ -2,7 +2,7 @@ use strict;
 
 use Inline;
 use Cwd;
-use constant BLIB => cwd('.') . '/.cpr_blib';
+use constant DIRECTORY => cwd('.') . '/.cpr';
 
 my (@cpr, @argv, $script);
 
@@ -15,11 +15,11 @@ BEGIN {
     close CPR;
     shift @cpr if $cpr[0] =~ /^\#\!/;
 
-    if (not -d BLIB) {
-	mkdir(BLIB, 0777) or die;
+    if (not -d DIRECTORY) {
+	mkdir(DIRECTORY, 0777) or die;
     }
 
-    Inline->import(CPR => [@cpr], BLIB => BLIB);
+    Inline->import(CPR => [@cpr], 
+		   DIRECTORY => DIRECTORY);
     exit &main::cpr_main();
 }
-    
